pub struct GetMessageEventResponse {
pub overview: Option<Box<GetMessageEventResponseOverview>>,
pub messages: Option<Vec<GetMessageEventResponseMessage>>,
pub clicks: Option<Vec<GetMessageEventResponseClick>>,
}Expand description
GetMessageEventResponse : Statistics about how users interact with narrowcast messages or broadcast messages sent from your LINE Official Account.
Fields
overview: Option<Box<GetMessageEventResponseOverview>>messages: Option<Vec<GetMessageEventResponseMessage>>Array of information about individual message bubbles.
clicks: Option<Vec<GetMessageEventResponseClick>>Array of information about opened URLs in the message.
Implementations
Sourceimpl GetMessageEventResponse
impl GetMessageEventResponse
Sourcepub fn new() -> GetMessageEventResponse
pub fn new() -> GetMessageEventResponse
Statistics about how users interact with narrowcast messages or broadcast messages sent from your LINE Official Account.