pub struct GetMessageEventResponseClick {
pub seq: Option<i32>,
pub url: Option<String>,
pub click: Option<Option<i64>>,
pub unique_click: Option<Option<i64>>,
pub unique_click_of_request: Option<Option<i64>>,
}Fields
seq: Option<i32>The URL’s serial number.
url: Option<String>URL.
click: Option<Option<i64>>Number of times the URL was opened.
unique_click: Option<Option<i64>>Number of users that opened the URL.
unique_click_of_request: Option<Option<i64>>Number of users who opened this url through any link in the message. If a message contains two links to the same URL and a user opens both links, they’re counted only once.
Implementations
Sourceimpl GetMessageEventResponseClick
impl GetMessageEventResponseClick
pub fn new() -> GetMessageEventResponseClick