pub struct GetMessageEventResponseMessage {
pub seq: Option<i32>,
pub impression: Option<Option<i64>>,
pub media_played: Option<Option<i64>>,
pub media_played25_percent: Option<Option<i64>>,
pub media_played50_percent: Option<Option<i64>>,
pub media_played75_percent: Option<Option<i64>>,
pub media_played100_percent: Option<Option<i64>>,
pub unique_media_played: Option<Option<i64>>,
pub unique_media_played25_percent: Option<Option<i64>>,
pub unique_media_played50_percent: Option<Option<i64>>,
pub unique_media_played75_percent: Option<Option<i64>>,
pub unique_media_played100_percent: Option<Option<i64>>,
}Fields
seq: Option<i32>Bubble’s serial number.
impression: Option<Option<i64>>Number of times the bubble was displayed.
media_played: Option<Option<i64>>Number of times audio or video in the bubble started playing.
media_played25_percent: Option<Option<i64>>Number of times audio or video in the bubble started playing and was played 25% of the total time.
media_played50_percent: Option<Option<i64>>Number of times audio or video in the bubble started playing and was played 50% of the total time.
media_played75_percent: Option<Option<i64>>Number of times audio or video in the bubble started playing and was played 75% of the total time.
media_played100_percent: Option<Option<i64>>Number of times audio or video in the bubble started playing and was played 100% of the total time.
unique_media_played: Option<Option<i64>>Number of users that started playing audio or video in the bubble.
unique_media_played25_percent: Option<Option<i64>>Number of users that started playing audio or video in the bubble and played 25% of the total time.
unique_media_played50_percent: Option<Option<i64>>Number of users that started playing audio or video in the bubble and played 50% of the total time.
unique_media_played75_percent: Option<Option<i64>>Number of users that started playing audio or video in the bubble and played 75% of the total time.
unique_media_played100_percent: Option<Option<i64>>Number of users that started playing audio or video in the bubble and played 100% of the total time.
Implementations