pub struct GetMessageEventResponseOverview {
pub request_id: Option<String>,
pub timestamp: Option<i64>,
pub delivered: Option<i64>,
pub unique_impression: Option<Option<i64>>,
pub unique_click: Option<Option<i64>>,
pub unique_media_played: Option<Option<i64>>,
pub unique_media_played100_percent: Option<Option<i64>>,
}Expand description
GetMessageEventResponseOverview : Summary of message statistics.
Fields
request_id: Option<String>Request ID.
timestamp: Option<i64>UNIX timestamp for message delivery time in seconds.
delivered: Option<i64>Number of messages delivered. This property shows values of less than 20. However, if all messages have not been sent, it will be null.
unique_impression: Option<Option<i64>>Number of users who opened the message, meaning they displayed at least 1 bubble.
unique_click: Option<Option<i64>>Number of users who opened any URL in the message.
unique_media_played: Option<Option<i64>>Number of users who started playing any video or audio in the message.
unique_media_played100_percent: Option<Option<i64>>Number of users who played the entirety of any video or audio in the message.
Implementations
Sourceimpl GetMessageEventResponseOverview
impl GetMessageEventResponseOverview
Sourcepub fn new() -> GetMessageEventResponseOverview
pub fn new() -> GetMessageEventResponseOverview
Summary of message statistics.